<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="zh_HK">
<context>
    <name>AIEnhanceFloatButton</name>
    <message>
        <source>Save</source>
        <translation type="obsolete">保存</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation type="obsolete">還原</translation>
    </message>
</context>
<context>
    <name>AIEnhanceFloatWidget</name>
    <message>
        <source>Save</source>
        <translation type="unfinished">保存</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="unfinished">另存爲</translation>
    </message>
    <message>
        <source>Reprovision</source>
        <translation type="unfinished">還原</translation>
    </message>
</context>
<context>
    <name>AIModelService</name>
    <message>
        <source>Save</source>
        <translation>保存</translation>
    </message>
    <message>
        <source>Save as</source>
        <translation type="unfinished">另存爲</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation type="unfinished">取 消</translation>
    </message>
    <message>
        <source>Image not saved, Do you want to save it?</source>
        <translation type="unfinished">圖片未保存，是否保存？</translation>
    </message>
    <message>
        <source>Image format is not supported, please switch the image.</source>
        <translation type="unfinished">圖像格式不支持，請切換圖片。</translation>
    </message>
    <message>
        <source>The image resolution exceeds the limit, please switch the image.</source>
        <translation type="unfinished">圖像分辨率超過限制，請切換圖片。</translation>
    </message>
    <message>
        <source>Portrait not detected, switch pictures.</source>
        <translation type="unfinished">未檢測到人像，請切換圖片。</translation>
    </message>
    <message>
        <source>OK</source>
        <translation type="unfinished">確定</translation>
    </message>
    <message>
        <source>This file is read-only, please save with another name.</source>
        <translation type="unfinished">該文件已設置為只讀，請使用其他文件名重試。</translation>
    </message>
    <message>
        <source>You do not have permission to save files here, please change and retry.</source>
        <translation type="unfinished">您沒有權限在此路徑保存文件，請重試。</translation>
    </message>
</context>
<context>
    <name>ExtensionPanel</name>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>Ctrl+I</source>
        <translation>Ctrl+I</translation>
    </message>
</context>
<context>
    <name>LibImageGraphicsView</name>
    <message>
        <source>AI retouching in progress, please wait...</source>
        <translation type="unfinished">AI修圖中，請稍等...</translation>
    </message>
</context>
<context>
    <name>LibImageInfoWidget</name>
    <message>
        <source>Basic info</source>
        <translation>基本訊息</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>詳細訊息</translation>
    </message>
</context>
<context>
    <name>LibViewPanel</name>
    <message>
        <source>Add to album</source>
        <translation>添加到相冊</translation>
    </message>
    <message>
        <source>New album</source>
        <translation>新建相冊</translation>
    </message>
    <message>
        <source>All images</source>
        <translation>所有圖片</translation>
    </message>
    <message>
        <source>Open Image</source>
        <translation>打開圖片</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>導出</translation>
    </message>
    <message>
        <source>Remove from album</source>
        <translation>從相冊中移除</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>取消收藏</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>收藏</translation>
    </message>
    <message>
        <source>Reset</source>
        <translation type="vanished">還原</translation>
    </message>
    <message>
        <source>Save</source>
        <translation type="vanished">保存</translation>
    </message>
    <message>
        <source>AI retouching</source>
        <translation type="unfinished">AI修圖</translation>
    </message>
</context>
<context>
    <name>LockWidget</name>
    <message>
        <source>You have no permission to view the image</source>
        <translation>沒有權限查看圖片</translation>
    </message>
</context>
<context>
    <name>MetadataName</name>
    <message>
        <source>Name</source>
        <translation>名稱</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>文件類型</translation>
    </message>
    <message>
        <source>Date modified</source>
        <translation>修改日期</translation>
    </message>
    <message>
        <source>File size</source>
        <translation>文件大小</translation>
    </message>
    <message>
        <source>Date captured</source>
        <translation>拍攝日期</translation>
    </message>
    <message>
        <source>Exposure mode</source>
        <translation>曝光模式</translation>
    </message>
    <message>
        <source>Exposure program</source>
        <translation>曝光程序</translation>
    </message>
    <message>
        <source>Exposure time</source>
        <translation>曝光時間</translation>
    </message>
    <message>
        <source>Flash</source>
        <translation>閃光燈</translation>
    </message>
    <message>
        <source>Aperture</source>
        <translation>光圈大小</translation>
    </message>
    <message>
        <source>Focal length</source>
        <translation>焦距</translation>
    </message>
    <message>
        <source>ISO</source>
        <translation>ISO感光度</translation>
    </message>
    <message>
        <source>Max aperture</source>
        <translation>最大光圈值</translation>
    </message>
    <message>
        <source>Metering mode</source>
        <translation>測光模式</translation>
    </message>
    <message>
        <source>White balance</source>
        <translation>白平衡</translation>
    </message>
    <message>
        <source>Flash compensation</source>
        <translation>閃光燈補償</translation>
    </message>
    <message>
        <source>Lens model</source>
        <translation>鏡頭型號</translation>
    </message>
    <message>
        <source>Colorspace</source>
        <translation>顏色空間</translation>
    </message>
    <message>
        <source>Camera model</source>
        <translation>相機型號</translation>
    </message>
    <message>
        <source>Dimensions</source>
        <translation>圖片尺寸</translation>
    </message>
    <message>
        <source>Tag</source>
        <translation>標記</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Back</source>
        <translation>返回</translation>
    </message>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>1:1 Size</source>
        <translation>1:1視圖</translation>
    </message>
    <message>
        <source>Fit to window</source>
        <translation>適應窗口</translation>
    </message>
    <message>
        <source>Extract text</source>
        <translation>識別文字</translation>
    </message>
    <message>
        <source>Rotate counterclockwise</source>
        <translation>逆時針旋轉</translation>
    </message>
    <message>
        <source>Rotate clockwise</source>
        <translation>順時針旋轉</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>刪除</translation>
    </message>
    <message>
        <source>Exit fullscreen</source>
        <translation>退出全屏</translation>
    </message>
    <message>
        <source>Fullscreen</source>
        <translation>全屏</translation>
    </message>
    <message>
        <source>Print</source>
        <translation>打印</translation>
    </message>
    <message>
        <source>Slide show</source>
        <translation>幻燈片放映</translation>
    </message>
    <message>
        <source>Copy</source>
        <translation>複製</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>重命名</translation>
    </message>
    <message>
        <source>Show navigation window</source>
        <translation>顯示導航窗口</translation>
    </message>
    <message>
        <source>Hide navigation window</source>
        <translation>隱藏導航窗口</translation>
    </message>
    <message>
        <source>Set as wallpaper</source>
        <translation>設為壁紙</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>在檔案管理員中顯示</translation>
    </message>
    <message>
        <source>Image info</source>
        <translation>圖片訊息</translation>
    </message>
    <message>
        <source>day</source>
        <translation type="vanished">天</translation>
    </message>
    <message>
        <source>Photo info</source>
        <translation>照片信息</translation>
    </message>
    <message>
        <source>Retry</source>
        <translation type="unfinished">重 試</translation>
    </message>
    <message>
        <source>Colorize pictures</source>
        <translation type="unfinished">圖片上色</translation>
    </message>
    <message>
        <source>Upgrade resolution</source>
        <translation type="unfinished">提升分辨率</translation>
    </message>
    <message>
        <source>Blurred background</source>
        <translation type="unfinished">模糊背景</translation>
    </message>
    <message>
        <source>Delete background</source>
        <translation type="unfinished">刪除背景</translation>
    </message>
    <message>
        <source>Hand-drawn cartoons</source>
        <translation type="unfinished">手繪漫畫</translation>
    </message>
    <message>
        <source>2D Manga</source>
        <translation type="unfinished">2D漫畫</translation>
    </message>
    <message>
        <source>Sketch</source>
        <translation type="unfinished">素描</translation>
    </message>
    <message>
        <source>Processing failure.</source>
        <translation type="unfinished">處理失敗。</translation>
    </message>
    <message>
        <source>3D Manga</source>
        <translation type="unfinished">3D漫畫</translation>
    </message>
</context>
<context>
    <name>RenameDialog</name>
    <message>
        <source>Confirm</source>
        <translation>確 定</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>取 消</translation>
    </message>
    <message>
        <source>Input a new name</source>
        <translation>請輸入圖片名稱</translation>
    </message>
    <message>
        <source>The file already exists, please use another name</source>
        <translation>文件名已被占用，請使用其他名稱</translation>
    </message>
</context>
<context>
    <name>SlideShowBottomBar</name>
    <message>
        <source>Previous</source>
        <translation>上一張</translation>
    </message>
    <message>
        <source>Pause</source>
        <translation>暫停</translation>
    </message>
    <message>
        <source>Play</source>
        <translation>播放</translation>
    </message>
    <message>
        <source>Next</source>
        <translation>下一張</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>退出</translation>
    </message>
</context>
<context>
    <name>ThumbnailWidget</name>
    <message>
        <source>No image files found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>Image file not found</source>
        <translation>未發現圖片文件</translation>
    </message>
    <message>
        <source>You have no permission to view the file</source>
        <translation>沒有權限查看文件</translation>
    </message>
</context>
</TS>
